@@ -6,6 +6,7 @@ import urllib
 import datetime
 
 from exceptions import NotFound
+from config import cfg
 
 
 class UrlMap(object):
@@ -44,17 +45,31 @@ class UrlMap(object):
             cur = node['next']
         if name:
             self.rev.setdefault(name, []).append(
-                ('/'.join(rev_chunks), len(vars)))
-        
+                ('/'.join(rev_chunks), vars))
+                
     def reverse(self, *args, **kwargs):
         name = args[0]
-        for tpl, var_cnt in self.rev.get(name):
-            if var_cnt != len(kwargs):
-                continue
-            try:
-                return urllib.quote(tpl % kwargs)
-            except (TypeError, KeyError):
-                pass
+        for tpl, vars in self.rev.get(name):
+            for k in vars:
+                if k not in kwargs:
+                    break
+            else:
+                try:
+                    url = urllib.quote(tpl % kwargs)
+                except (TypeError, KeyError):
+                    pass
+                else:
+                    # GET параметры
+                    if len(kwargs) > len(vars):
+                        ext_vars = {}
+                        for k, v in kwargs.iteritems():
+                            if k not in vars:
+                                if isinstance(v, unicode):
+                                    v = v.encode(cfg.CHARSET)
+                                ext_vars[k] = v
+                        if ext_vars:
+                            url += '?' + urllib.urlencode(ext_vars)
+                    return url
     
     def find(self, url):
         dirs = url.split('/')[1:]
